searchData={"items":[{"type":"module","title":"Unicode.Guards","doc":"Defines a set of guards that can be used with\nElixir functions.\n\nEach guard operates on a UTF8 codepoint since\nthe permitted operators in a guard clause\nare restricted to simple comparisons that do\nnot include string comparators.\n\nThe data that underpins these guards is generated\nfrom the Unicode character database and therefore\nincludes a broad range of scripts well beyond\nthe basic ASCII definitions.","ref":"Unicode.Guards.html"},{"type":"macro","title":"Unicode.Guards.is_blank/1","doc":"Guards whether a UTF8 codepoint is a space character.\n\nThis is the Unicode definition of those characters that\nhorizontal space (space, non-breaking space etc) as well\nas the horizontal tab character.","ref":"Unicode.Guards.html#is_blank/1"},{"type":"macro","title":"Unicode.Guards.is_currency_symbol/1","doc":"Guards whether a UTF8 codepoint is a currency symbol\ncharacter.","ref":"Unicode.Guards.html#is_currency_symbol/1"},{"type":"macro","title":"Unicode.Guards.is_digit/1","doc":"Guards whether a UTF8 codepoint is a digit\ncharacter.\n\nThis guard will match any digit character from any\nUnicode script, not only the ASCII decimal digits.","ref":"Unicode.Guards.html#is_digit/1"},{"type":"macro","title":"Unicode.Guards.is_graph/1","doc":"Guards whether a UTF8 codepoint is a graphic character.\n\nThis is the Unicode definition of those characters that\nare visible. It is defined as those characters that are\nnon-space, non-control and non-surrogate.","ref":"Unicode.Guards.html#is_graph/1"},{"type":"macro","title":"Unicode.Guards.is_lower/1","doc":"Guards whether a UTF8 codepoint is a lower case\ncharacter.\n\nThe match is for any UTF8 character that is defined\nin Unicode to be an lower case character in any\nscript.","ref":"Unicode.Guards.html#is_lower/1"},{"type":"macro","title":"Unicode.Guards.is_print/1","doc":"Guargs where a UTF8 codepoint is a printing character.\n\nThis is the Unicode definition which is a combination of the\n`[:graph:]` set and the `[:blank:]` set.","ref":"Unicode.Guards.html#is_print/1"},{"type":"macro","title":"Unicode.Guards.is_printable/1","doc":"Guards whether a UTF8 codepoint is a printable.\n\nThe definition of what is printable is the same as\nused by `String.printable?/1`","ref":"Unicode.Guards.html#is_printable/1"},{"type":"macro","title":"Unicode.Guards.is_quote_mark/1","doc":"Guards whether a UTF8 codepoint is a unicode quote symbol\ncharacter.\n\nThis includes the Unicode set `Pi`, `Pf` and\nother characters documents in this [Wikpedia article](https://en.wikipedia.org/wiki/Quotation_mark).\n\nSee also `Unicode.Category.QuoteMarks`.","ref":"Unicode.Guards.html#is_quote_mark/1"},{"type":"macro","title":"Unicode.Guards.is_quote_mark_ambidextrous/1","doc":"Guards whether a UTF8 codepoint is a unicode quote symbol that can\nbe used either left or right.\n\nSee also `Unicode.Category.QuoteMarks`.","ref":"Unicode.Guards.html#is_quote_mark_ambidextrous/1"},{"type":"macro","title":"Unicode.Guards.is_quote_mark_double/1","doc":"Guards whether a UTF8 codepoint is a unicode quote symbol that is\nconsidered a single quote.\n\nSee also `Unicode.Category.QuoteMarks`.","ref":"Unicode.Guards.html#is_quote_mark_double/1"},{"type":"macro","title":"Unicode.Guards.is_quote_mark_left/1","doc":"Guards whether a UTF8 codepoint is a unicode left quote symbol\ncharacter.\n\nSee also `Unicode.Category.QuoteMarks`.","ref":"Unicode.Guards.html#is_quote_mark_left/1"},{"type":"macro","title":"Unicode.Guards.is_quote_mark_right/1","doc":"Guards whether a UTF8 codepoint is a unicode right quote symbol\ncharacter.\n\nSee also `Unicode.Category.QuoteMarks`.","ref":"Unicode.Guards.html#is_quote_mark_right/1"},{"type":"macro","title":"Unicode.Guards.is_quote_mark_single/1","doc":"Guards whether a UTF8 codepoint is a unicode quote symbol that is\nconsidered a single quote.\n\nSee also `Unicode.Category.QuoteMarks`.","ref":"Unicode.Guards.html#is_quote_mark_single/1"},{"type":"macro","title":"Unicode.Guards.is_separator/1","doc":"Guards whether a UTF8 codepoint is a unicode separator symbol\ncharacter.\n\nThis includes the Unicode set `Zs` plus the characters.","ref":"Unicode.Guards.html#is_separator/1"},{"type":"macro","title":"Unicode.Guards.is_upper/1","doc":"Guards whether a UTF8 codepoint is an upper case\ncharacter.\n\nThe match is for any UTF8 character that is defined\nin Unicode to be an upper case character in any\nscript.","ref":"Unicode.Guards.html#is_upper/1"},{"type":"macro","title":"Unicode.Guards.is_whitespace/1","doc":"Guards whether a UTF8 codepoint is a whitespace symbol\ncharacter.\n\nThis includes the Unicode set `Zs` plus the characters in the range `0x9`-`0xd`\nwhich incudes tab, newline and carriage return.","ref":"Unicode.Guards.html#is_whitespace/1"},{"type":"extras","title":"Unicode Guards","doc":"# Unicode Guards\n\nProvides a set of function guards that can be used to match Unicode codepoints.  Based upon [ex_unicode](https://hex.pm/packages/ex_unicode) and [unicode_set](https://hex.pm/packages/unicode_set).","ref":"readme.html"},{"type":"extras","title":"Usage - Unicode Guards","doc":"Each guard operates on a UTF8 codepoint since the permitted operators in a guard clause are restricted to simple comparisons that do not include strings.\n\nThe data that underpins these guards is generated from the Unicode character database and therefore\nincludes a broad range of scripts well beyond the basic ASCII definitions.\n\nSome examples follow defining functions using the pre-defined guards. Note that since guards operate on codepoints (not strings) we use binary pattern matching to extract the first codepoint for these example.\n\n```elixir\ndefmodule Guards do\n  import Unicode.Guards\n\n  def upper(< >) when is_upper(x), do: :upper\n  def lower(< >) when is_lower(x), do: :lower\n  def digit(< >) when is_digit(x), do: :digit\n  def whitespace(< >) when is_whitespace(x), do: :whitespace\n  def currency(< >) when is_currency_symbol(x), do: :currency\nend\n```","ref":"readme.html#usage"},{"type":"extras","title":"Installation - Unicode Guards","doc":"The package can be installed by adding `unicode_guards` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:unicode_guards, \"~> 1.0\"}\n  ]\nend\n```\n\nThe docs can be found at [https://hexdocs.pm/unicode_guards](https://hexdocs.pm/unicode_guards).","ref":"readme.html#installation"},{"type":"extras","title":"License","doc":"# License\n\nCopyright 2019 Kip Cole\n\nLicensed under the Apache License, Version 2.0 (the \"License\"); you may not use this file except in\ncompliance with the License. You may obtain a copy of the License at\n\n    http://www.apache.org/licenses/LICENSE-2.0\n\nUnless required by applicable law or agreed to in writing, software distributed under the License\nis distributed on an \"AS IS\" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or\nimplied. See the License for the specific language governing permissions and limitations under the\nLicense.","ref":"license.html"},{"type":"extras","title":"Changelog","doc":"# Changelog","ref":"changelog.html"},{"type":"extras","title":"Unicode Guards v1.0.1 - Changelog","doc":"This is the changelog for Unicode Guards v1.0.1 released on February 21st, 2025.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-unicode/unicode_guards/tags)","ref":"changelog.html#unicode-guards-v1-0-1"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Use `defmacro` instead of `defguard` for some guards to avoid implementation limits on OTP 27. Issue to be explored further upstream with Elixir and OTP. THanks to @vlemann for the PR, greatly appreciated. Closes #9.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Unicode Guards v1.0.0 - Changelog","doc":"This is the changelog for Unicode Guards v1.0.0 released on September 14th, 2021.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-unicode/unicode_guards/tags)","ref":"changelog.html#unicode-guards-v1-0-0"},{"type":"extras","title":"Enhancments - Changelog","doc":"* Update to use [Unicode 14](https://unicode.org/versions/Unicode14.0.0) release data.","ref":"changelog.html#enhancments"},{"type":"extras","title":"Unicode Guards v0.5.1 - Changelog","doc":"This is the changelog for Unicode Guards v0.5.1 released on May 25th, 2021.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-unicode/unicode_guards/tags)","ref":"changelog.html#unicode-guards-v0-5-1"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Fix dependency configuration to mark `ex_doc` and `benchee` as optional. Thanks to @everettvody.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Unicode Guards v0.5.0 - Changelog","doc":"This is the changelog for Unicode Guards v0.5.0 released on December 5th, 2020.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-unicode/unicode_guards/tags)","ref":"changelog.html#unicode-guards-v0-5-0"},{"type":"extras","title":"Bug FIxes - Changelog","doc":"* Relax version requirement for `nimble_parsec` to allow `\"~> 0.5 or ~> 1.0\"`. Thanks to @@fireproofsocks.  Closes #3.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Unicode Guards v0.4.0 - Changelog","doc":"This is the changelog for Unicode Guards v0.4.0 released on October 13th, 2020.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-unicode/unicode_guards/tags)","ref":"changelog.html#unicode-guards-v0-4-0"},{"type":"extras","title":"Bug FIxes - Changelog","doc":"* Fix `ex_doc` dependency. Thanks to @nickdichev.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Add additional guards `is_graph?/1`, `is_blank?/1` and `is_print/1` that match the definitions for Unicode regexes.","ref":"changelog.html#enhancements"},{"type":"extras","title":"Unicode Guards v0.3.1 - Changelog","doc":"This is the changelog for Unicode Guards v0.3.1 released on May 21st, 2020.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-unicode/unicode_guards/tags)","ref":"changelog.html#unicode-guards-v0-3-1"},{"type":"extras","title":"Bug FIxes - Changelog","doc":"* Fix escape sequences in `is_whitespace/2` guard. Thanks to @nickdichev, closes #1","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Unicode Guards v0.3.0 - Changelog","doc":"This is the changelog for Unicode Guards v0.3.0 released on March 14th, 2020.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-unicode/unicode_guards/tags)","ref":"changelog.html#unicode-guards-v0-3-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Add `is_printable/1` that uses the same semantics as `String.printable?/1`\n* Add `is_visible/1` that uses the Unicode set `[[:L:][:N:][:M:][:P:][:S:][:Zs:]]`","ref":"changelog.html#enhancements"},{"type":"extras","title":"Unicode Guards v0.2.0 - Changelog","doc":"This is the changelog for Unicode Guards v0.2.0 released on March 11th, 2020.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-unicode/unicode_guards/tags)","ref":"changelog.html#unicode-guards-v0-2-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Add guards for quote marks. Adds:\n\n  * `is_quote_mark/1`\n  * `is_quote_mark_left/1`\n  * `is_quote_mark_right/1`\n  * `is_quote_mark_ambidextrous/1`\n  * `is_quote_mark_single/1`\n  * `is_quote_mark_double/1`","ref":"changelog.html#enhancements"},{"type":"extras","title":"Unicode Guards v0.1.1 - Changelog","doc":"This is the changelog for Unicode Guards v0.1.1 released on February 25th, 2020.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-unicode/unicode_guards/tags)","ref":"changelog.html#unicode-guards-v0-1-1"},{"type":"extras","title":"Bug FIxes - Changelog","doc":"* Corrects `is_whitespace/1` to include the expected characters in the range `0x9-0xd`. These comprise carriage return, newline, vertical tab and tab which are commonly considered by regex engines to be whitespace.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Unicode Guards v0.1.0 - Changelog","doc":"This is the changelog for Unicode Guards v0.1.0 released on November 23rd, 2019.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-unicode/unicode_guards/tags)\n\nInitial release.","ref":"changelog.html#unicode-guards-v0-1-0"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.37.2"}}